/*:
* @target MZ
* @plugindesc Enemy Levels
* @author Marrend
*
* @help enemy_levels.js
*
* This plugin allows users to insert a note-tag to set an enemy's level for varying purposes.
*
* It has a built-in parameter to multiply rewards (ie: xp and gold) by the enemy's level, defined as a boolean variable.
*
* @param level_mult
* @text Level multiplier
* @desc When enabled, multiples exp and gold awards.
* @default false
* @type boolean
*/

// Function taken from https://forums.rpgmakerweb.com/index.php?threads/plugin-parameters-boolean-eval.114799/
// The author of the post is LTN Games, and the code was adapted from work by waynee95.
function convertParameters(parameters) {
	function parseParameters(string) {
		try {
			return JSON.parse(string, (key, value) => {
				try {
					return parseParameters(value);
				} catch (e) {
					return value;
				}
			});
		} catch (e) {
			return string;
		}
	}
	return parseParameters(JSON.stringify(parameters));
};

(() => {
	var raw_params = PluginManager.parameters('enemy_levels');
	var obj = convertParameters(raw_params);

	Object.defineProperty(Game_Enemy.prototype, "level", {
		get: function() {
			notes = $dataEnemies[this._enemyId].meta;
			if (notes.level) {
				return Number(notes.level);
			} else {
				return 1;
			};
		}
	});

	const game_enemy_exp = Game_Enemy.prototype.exp;
	// Aliased function.
	Game_Enemy.prototype.exp = function() {
		if (obj.level_mult === true) {
			return game_enemy_exp.apply(this) * this.level;
		} else {
			return game_enemy_exp.apply(this)
		}
	};
	
	const game_enemy_gold = Game_Enemy.prototype.gold;
	// Aliased function.
	Game_Enemy.prototype.gold = function() {
		if (obj.level_mult === true) {
			return game_enemy_exp.apply(this) * this.level;
		} else {
			return game_enemy_exp.apply(this)
		}
	};
})();
