/*:
* @target MZ
* @plugindesc HoMM Damage formula
* @author Marrend
*
* @help homm_damage.js
*
* This plugin provides a standard damage formula derived from the Heroes of Might and Magic series.
*
* Example:
*
* damage(25, a.atk, b.def);
* damage(1, a.atk*3, 0);
* damage(100, a.atk, d.def*3);
*
* It does not provide plugin commands.
*/

function damage(base, atk_p, def_p) {
	// Damage is equal to the base multiplied by a "damage multiplier". This multiplier is calculated
	// via a percentage based on the difference between the attacker's attack-stat and the
	// defender's defense-stat.
    
	// Original method, as per the actual Heroes formula.
	//m = 1.0 + ((atk_p - def_p) / 16.0);
	// coelocanth's fix, slightly edited
    if(atk_p >= def_p) {
        m = 1.0 + (Math.sqrt(atk_p - def_p) / 8.0)
    } else {
        m = 1.0 - (Math.sqrt(def_p - atk_p) / 8.0)
    };

	// Now that we know the "damage multiplier", it's time to do the calculation.
	// The result is a floating-point, so, we round up afterwards.
	result = Math.ceil(base * m);
  
	if (result < 1) {
		result = 1;  // Minimum damage value is 1.
	}
	return result;
};
